@@ -3,7 +3,7 @@ package Dist::Mgr::FileData;
 use warnings;
 use strict;
 
-our $VERSION = '1.08_02';
+our $VERSION = '1.01';
 
 use Exporter qw(import);
 our @ISA = qw(Exporter);
@@ -12,8 +12,6 @@ our @EXPORT_OK = qw(
 
     _ci_github_file
 
-    _config_file
-
     _git_ignore_file
 
     _module_section_ci_badges
@@ -105,13 +103,6 @@ sub _ci_github_file {
     );
 }
 
-sub _config_file {
-    return {
-        cpan_id     => '',
-        cpan_pw     => '',
-    };
-}
-
 sub _git_ignore_file {
     return (
         q{Makefile},
@@ -365,11 +356,6 @@ internally.
         w => qq{windows-latest},
         m => qq{macos-latest},
 
-=head2 _config_file
-
-Returns a hash reference containing the data that makes up a default
-configuration file.
-
 =head2 _git_ignore_file()
 
 Returns an array of the contents of a populated C<.gitignore> file.
