@@ -29,14 +29,14 @@ our @EXPORT_OK = qw(
     _git_pull
     _git_release
     _git_repo
-    _git_status_differs
+    _git_status
     _git_tag
 );
 our %EXPORT_TAGS = (
     all     => [@EXPORT_OK],
 );
 
-our $VERSION = '1.08_02';
+our $VERSION = '1.01';
 
 my $spinner_count;
 
@@ -116,10 +116,10 @@ sub _git_clone {
     return $?;
 }
 sub _git_pull {
-    my ($verbose) = @_;
+    my ($version) = @_;
 
     if (_validate_git()) {
-        _exec('git pull', $verbose);
+        `git pull`;
         croak("Git pull failed with exit code: $?") if $? != 0;
     }
     else {
@@ -147,17 +147,16 @@ sub _git_release {
 
     croak("git_release() requires a version sent in") if ! defined $version;
 
-    my $git_status_differs = _git_status_differs();
     $wait_for_ci //= 1;
     my $verbose = 0;
 
-    if ($git_status_differs) {
-        _git_pull();
+    if (! _git_status()) {
+        _git_pull(0);
         _git_commit($version, $verbose);
         _git_push($verbose);
     }
 
-    if ($wait_for_ci && $git_status_differs) {
+    if ($wait_for_ci) {
         `clear`;
 
         print "\n\nWaiting for CI tests to complete.\n\n";
@@ -185,8 +184,6 @@ sub _git_release {
             return 0;
         }
     }
-
-    return 1;
 }
 sub _git_repo {
     my $repo;
@@ -205,7 +202,7 @@ sub _git_repo {
         return $?;
     }
 }
-sub _git_status_differs {
+sub _git_status {
     my $status_output;
 
     if (_validate_git()) {
@@ -224,10 +221,10 @@ sub _git_status_differs {
     my @status = split /\n/, $status_output;
 
     for (0..$#status) {
-        return 1 if $status[$_] !~ /$git_output[$_]/;
+        return 0 if $status[$_] !~ /$git_output[$_]/;
     }
 
-    return 0;
+    return 1;
 }
 sub _git_tag {
     my ($version, $verbose) = @_;
