@@ -22,9 +22,6 @@ our @EXPORT_OK = qw(
     copy_manifest
     copy_git_ignore
 
-    cpan_save
-    cpan_restore
-
     unlink_changes
     unlink_ci_files
     unlink_makefile
@@ -50,7 +47,7 @@ our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
 my $orig_dir        = 't/data/orig';
 my $work_dir        = 't/data/work';
-my $tpl_dir         = 't/data/template/module_template';
+my $tpl_dir         = 't/data/module_template';
 my $unwanted_dir    = 't/data/work/unwanted';
 my $init_dir        = 't/data/work/init';
 my $ci_dir          = 't/data/work/ci';
@@ -99,21 +96,6 @@ sub copy_git_ignore {
     copy "$orig_dir/.gitignore", $work_dir or die $!;
 }
 
-sub cpan_save {
-    my $f = "$ENV{HOME}/dist-mgr.json";
-
-    if (-e $f) {
-        copy $f, "$f.bak" or die "Can't copy config file: $!";
-    }
-}
-sub cpan_restore {
-    my $f = "$ENV{HOME}/dist-mgr.json";
-
-    if (-e "$f.bak") {
-        copy "$f.bak", $f or die "Can't copy config file: $!";
-    }
-}
-
 sub unlink_changes {
     if (-e "$work_dir/Changes") {
         unlink "$work_dir/Changes" or die $!;
@@ -185,11 +167,7 @@ sub file_compare {
     close $orig_fh or die $!;
 
     for (0..$#new) {
-        $new[$_] =~ s/[\r\n]//g;
-        $orig[$_] =~ s/[\r\n]//g;
-        chomp $orig;
-
-        like $new[$_], qr/^$orig[$_]/, "Updated Changes file line $_ matches template custom ok";
+        is $new[$_], $orig[$_], "Updated Changes file line $_ matches template custom ok";
     }
 }
 sub file_scalar {
@@ -248,17 +226,6 @@ sub trap_warn {
     }
 }
 
-sub make_second_module {
-    my ($dest) = @_;
-
-    if (! -e $dest) {
-        mkdir $dest or die "Can't create $dest dir\n";
-        is -d $dest, 1, "$dest dir created ok";
-    }
-
-    copy 't/data/orig/One.pm', $dest or die "Can't copy One.pm to $dest\n";
-
-}
 sub module_args {
     my %module_args = (
         author  => 'Test Author',
@@ -307,4 +274,4 @@ sub verify_clean {
     is(scalar(find_module_files($work_dir)), 0, "all work module files unlinked ok");
 }
 
-1;
+1;
\ No newline at end of file
